package org.dive4elements.river.artifacts.model.minfo;

import org.apache.log4j.Logger;

import org.dive4elements.artifactdatabase.state.Facet;
import org.dive4elements.artifacts.Artifact;
import org.dive4elements.artifacts.CallContext;
import org.dive4elements.river.artifacts.FLYSArtifact;
import org.dive4elements.river.artifacts.model.CalculationResult;
import org.dive4elements.river.artifacts.model.DataFacet;
import org.dive4elements.river.artifacts.states.DefaultState.ComputeType;


/**
 * Facet for serving bed porosity data.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class BedPorosityFacet extends DataFacet {

    private static final long serialVersionUID = 1L;

    private static Logger logger = Logger.getLogger(BedPorosityFacet.class);

    public BedPorosityFacet() {
    }

    public BedPorosityFacet(int idx, String name, String description,
        ComputeType type, String stateId, String hash) {
        super(idx, name, description, type, hash, stateId);
    }

    public Object getData(Artifact artifact, CallContext context) {
        logger.debug("Get data for bed porosity at index: " + index);

        FLYSArtifact flys = (FLYSArtifact) artifact;

        CalculationResult res = (CalculationResult) flys.compute(context, hash,
            stateId, type, false);

        int ndx = index >> 8;
        Object[] data = ((BedQualityResult[]) res.getData())[ndx].getParameters(); // TODO CAST TO SPECIFIC CLASS

        int ndy = index & 255;
        return data != null && data.length > ndy ? data[ndy] : null;
    }

    /** Copy deeply. */
    @Override
    public Facet deepCopy() {
        BedPorosityFacet copy = new BedPorosityFacet();
        copy.set(this);
        copy.type = type;
        copy.hash = hash;
        copy.stateId = stateId;
        return copy;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
